==> coal_library-3.0.0-0-cp312-cp312-macosx_11_0_arm64.whl: cmeel.prefix/lib/cmake/coal/coalTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "coal::coal" for configuration "Release"
set_property(TARGET coal::coal APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(coal::coal PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "assimp::assimp"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libcoal.dylib"
  IMPORTED_SONAME_RELEASE "@rpath/libcoal.dylib"
  )

list(APPEND _cmake_import_check_targets coal::coal )
list(APPEND _cmake_import_check_files_for_coal::coal "${_IMPORT_PREFIX}/lib/libcoal.dylib" )

# Import target "coal::coal_pywrap" for configuration "Release"
set_property(TARGET coal::coal_pywrap APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(coal::coal_pywrap PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${PACKAGE_PREFIX_DIR}/lib/python3.12/site-packages/coal/coal_pywrap.cpython-312-darwin.so"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _cmake_import_check_targets coal::coal_pywrap )
list(APPEND _cmake_import_check_files_for_coal::coal_pywrap "${PACKAGE_PREFIX_DIR}/lib/python3.12/site-packages/coal/coal_pywrap.cpython-312-darwin.so" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> coal_library-3.0.1-0-cp312-cp312-macosx_11_0_arm64.whl: cmeel.prefix/lib/cmake/coal/coalTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "coal::coal" for configuration "Release"
set_property(TARGET coal::coal APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(coal::coal PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "assimp::assimp;Qhull::qhull_r"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libcoal.3.0.1.dylib"
  IMPORTED_SONAME_RELEASE "@rpath/libcoal.3.0.1.dylib"
  )

list(APPEND _cmake_import_check_targets coal::coal )
list(APPEND _cmake_import_check_files_for_coal::coal "${_IMPORT_PREFIX}/lib/libcoal.3.0.1.dylib" )

# Import target "coal::coal_pywrap" for configuration "Release"
set_property(TARGET coal::coal_pywrap APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(coal::coal_pywrap PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${PACKAGE_PREFIX_DIR}/lib/python3.12/site-packages/coal/coal_pywrap.cpython-312-darwin.so"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _cmake_import_check_targets coal::coal_pywrap )
list(APPEND _cmake_import_check_files_for_coal::coal_pywrap "${PACKAGE_PREFIX_DIR}/lib/python3.12/site-packages/coal/coal_pywrap.cpython-312-darwin.so" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
